{% extends 'infra_optim/base.html' %}
{% load i18n %}
{% block title %}{% trans 'Audit Templates: ' %}{{ audit_template.name }}{% endblock %}

{% block page_header %}
  {% include 'horizon/common/_page_header.html' with title=_('Audit Templates: ')|add:audit_template.name %}
{% endblock page_header %}

{% block main %}
<div class="row">
  <div class="detail col-md-6">
    <h4>{% trans "Audit Template Info" %}</h4>
    <dl class="dl-horizontal">
        <dt>{% trans "Name" %}</dt>
        <dd>{{ audit_template.name|default:_("-") }}</dd>
        <dt>{% trans "UUID" %}</dt>
        <dd>{{ audit_template.uuid|default:_("-") }}</dd>
        <dt>{% trans "Goal" %}</dt>
        <dd>{{ audit_template.goal_name|default:_("-") }}</dd>
        <dt>{% trans "Strategy" %}</dt>
        <dd>{{ audit_template.strategy_name|default:_("-") }}</dd>
        <dt>{% trans "Audit Scope" %}</dt>
        <dd><code>{{ audit_template.scope|linebreaks }}</code></dd>
        <dt>{% trans "Created At" %}</dt>
        <dd>{{ audit_template.created_at|parse_isotime|default:_("-") }}</dd>
        <dt>{% trans "Update At" %}</dt>
        <dd>{{ audit_template.updated_at|parse_isotime|default:_("-") }}</dd>
        <dt>{% trans "Deleted At" %}</dt>
        <dd>{{ audit_template.deleted_at|parse_isotime|default:_("-") }}</dd>
    </dl>
  </div>
</div>
<div class="row">
  <div class="col-xs-12">
    {{ table.render }}
  </div>
</div>

{% endblock %}
