{% extends 'infra_optim/base.html' %}

{% block main %}

<div class="row">
  <div class="col-xs-12">
    {% block breadcrumbs %}{% endblock %}

    <div class="pull-right btn-toolbar">
      {% block actions %}{% endblock %}
    </div>

    <h3>{% block name %}{% endblock %}</h3>
  </div>
</div>

<div class="row">
  <div class="col-xs-12">
    <div class="pull-right">
      {% block overall_usage %}{% endblock %}
    </div>

    {{ tab_group.render }}
  </div>
</div>

{% endblock %}
