{% extends "horizon/common/_modal_form.html" %}
{% load i18n %}

{% block modal-body-right %}
  <h3>{% trans "Description:" %}</h3>
  <p>{% trans "Creates an audit template with specified parameters." %}</p>
  <p>
    <span>{% trans "Define the optimization goal to achieve, among those which are available." %}</span>
    <span>{% trans "Optionally, you can select the strategy used to achieve your goal. If not set, a strategy will be automatically selected among those which can be used for your goal" %}</span>
  </p>
  <h3>{% trans "Audit scope:" %}</h3>
  <p>{% trans "Creates an audit template with specified parameters." %}</p>

<p class="scope-example-yaml">
    {% trans "YAML example:" %}
    ---
     - compute:
       - host_aggregates:
         - id: 1
         - id: 2
         - id: 3
       - availability_zones:
         - name: AZ1
         - name: AZ2
       - exclude:
         - instances:
           - uuid: UUID1
          - uuid: UUID2
         - compute_nodes:
           - name: compute1
  </p>
  <p>
    {% trans "JSON example:" %}
    [{'compute':
        [{'host_aggregates': [
             {'id': 1},
             {'id': 2},
             {'id': 3}]},
         {'availability_zones': [
             {'name': 'AZ1'},
             {'name': 'AZ2'}]},
         {'exclude': [
             {'instances': [
                 {'uuid': 'UUID1'},
                 {'uuid': 'UUID2'}
             ]},
             {'compute_nodes': [
                 {'name': 'compute1'}
             ]}
        ]}]
    }]
</p>
{% endblock %}
