{% extends 'infra_optim/base.html' %}
{% load i18n %}
{% block title %}{% trans 'Audits' %}{% endblock %}
 
{% block page_header %}
  {% include 'horizon/common/_items_count_domain_page_header.html' with title=_('Audits') items_count=flavors_count %}
{% endblock page_header %}
 
{% block main %}
{% if suggested_flavors_count %}
<table id="suggested-flavors-header" class="table">
  <thead>
  <tr data-toggle="collapse" href="#suggested-flavors">
    <th class="col-xs-11">
      <a href="#suggested-flavors">{{ suggested_flavors_count }}&times; Suggested Flavor</a>
    </th>
    <th class="col-xs-1">
      <a class="pull-right" href="#suggested-flavors">
        <span class="caret"></span>
      </a>
    </th>
  </tr>
  </thead>
</table>
 
<div id="suggested-flavors" class="panel-collapse collapse">
  {{ suggested_flavors_table.render }}
</div>
{% endif %}
 
<div id="audits">
  {{ audits_table.render }}
</div>
{% endblock %}
