{% extends 'base.html' %}
{% load i18n %}
{% block title %}{% trans "Action Plan Details"%}{% endblock %}

{% block main %}
<div class="row">
  <div class="col-sm-12">
    {% include "infra_optim/action_plans/_details_overview.html" %}
    <hr>
    <div id="efficacy_indicators">
      {{ related_efficacy_indicators_table.render }}
    </div>
    <div id="wactions">
      {{ related_wactions_table.render }}
    </div>
  </div>
</div>
{% endblock %}
