{% extends 'base.html' %}

{% block css %}
  {{block.super}}

  {% load compress %}
  {% compress css %}
  <link href='{{ STATIC_URL }}infra_optim/scss/infra_optim.scss' type='text/scss' media='screen' rel='stylesheet' />
  <link href="{{ STATIC_URL }}horizon/lib/font_awesome/css/font-awesome.css" type="text/css" media="screen" rel="stylesheet" />

  {% endcompress %}
{% endblock %}
