{% load i18n %}
{% block page_header %}
  <div class='page-header'>
    {% include 'infra_optim/header_actions.html' %}
    <h1>
    {% if request.session.domain_context_name %}
      <em>{{ request.session.domain_context_name }}:</em>
    {% endif %}
    {{ title }}
      {% if items_count or items_count == 0%}
      <span class="badge">
        {{ items_count }}
      </span>
      {% endif %}
    </h1>
  </div>
{% endblock %}
