{% extends 'infra_optim/base.html' %}
{% load i18n %}
{% block title %}{% trans 'Goals: ' %}{{ goal.display_name }}{% endblock %}

{% block page_header %}
  {% include 'horizon/common/_page_header.html' with title=_('Goals: ')|add:goal.display_name %}
{% endblock page_header %}

{% block main %}
<div class="row">
  <div class="detail col-md-6">
    <h4>{% trans "Goal Info" %}</h4>
    <dl class="dl-horizontal">
        <dt>{% trans "UUID" %}</dt>
        <dd>{{ goal.uuid|default:_("-") }}</dd>
        <dt>{% trans "Name" %}</dt>
        <dd>{{ goal.display_name|default:_("-") }}</dd>
        <dt>{% trans "Created At" %}</dt>
        <dd>{{ goal.created_at|parse_isotime|default:_("-") }}</dd>
        <dt>{% trans "Update At" %}</dt>
        <dd>{{ goal.updated_at|parse_isotime|default:_("-") }}</dd>
    </dl>
  </div>
</div>
<div class="row detail col-md-12">
  <div id="efficacy_specification">
    {{ efficacy_specification_table.render }}
  </div>
  <div id="strategies">
    {{ related_strategies_table.render }}
  </div>
</div>

{% endblock %}
