<h4>{{ label }}</h4>
<div class="overview_chart">
  <div class="chart_container">
    <div class="chart"
         data-chart-type="line_chart"
         data-url="{{ url }}"
         data-form-selector='#linechart_general_form'
         data-settings='{ "auto_size": false, "axes_x" : false, "axes_y" : false {% if y_max %}, "yMax": {{ y_max }} {% endif %} }'>
    </div>
  </div>
  <div class="bar_chart_container">
    <div class="chart"
      data-chart-type="overview_bar_chart">
    </div>
  </div>
</div>
